summaryrefslogtreecommitdiffhomepage
path: root/examples/models
diff options
context:
space:
mode:
authorlumaio teon <[email protected]>2018-04-07 04:00:06 -0400
committerlumaio teon <[email protected]>2018-04-07 04:00:06 -0400
commit7bd0f8b28c4cd576ab5c3e7b696d408f0f8045e4 (patch)
treee192b288320a9c32f3d2b8d040a91c36976649dc /examples/models
parentd2cc5b88dfa3ff8bbcd66a4849cd3be1d553b6f1 (diff)
downloadraylib-7bd0f8b28c4cd576ab5c3e7b696d408f0f8045e4.tar.gz
raylib-7bd0f8b28c4cd576ab5c3e7b696d408f0f8045e4.zip
Fix mesh picking example
Diffstat (limited to 'examples/models')
-rw-r--r--examples/models/models_mesh_picking.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/models/models_mesh_picking.c b/examples/models/models_mesh_picking.c
index 1cc38b45..e09f9860 100644
--- a/examples/models/models_mesh_picking.c
+++ b/examples/models/models_mesh_picking.c
@@ -101,8 +101,8 @@ int main()
{
hitMeshBBox = true;
- // Check ray collision against mesh
- meshHitInfo = GetCollisionRayMesh(ray, &tower.mesh);
+ // Check ray collision against model
+ meshHitInfo = GetCollisionRayModel(ray, &tower);
if ((meshHitInfo.hit) && (meshHitInfo.distance < nearestHit.distance))
{